summaryrefslogtreecommitdiff
path: root/vcl/inc/fontinstance.hxx
diff options
context:
space:
mode:
authorChris Sherlock <chris.sherlock79@gmail.com>2016-01-12 14:47:34 +1100
committerChris Sherlock <chris.sherlock79@gmail.com>2016-01-12 05:36:04 +0000
commitb4b0cc2a5eef42434444e51fda4a13fc48183aa0 (patch)
tree1061efa135f480b37c90879d7c049872d0e738eb /vcl/inc/fontinstance.hxx
parent414c5c5aee8692614e4e5a5f97d11bea157bcaef (diff)
vcl: resplit FontAttributes from ImplFontMetricData
The change I made in commit 7b974e056df3 ("vcl: merge ImplFontMetricData with ImplFontAttributes") was... ill-advised. For starters, there really needs to be this split as FontSelectPattern needs it, and PhysicalFontFace only requires the font attributes, not the metric data. So the merge was unfortunately, in my mind, a failure and I'm manually backing it out now. Change-Id: Iac38f0815f984541e2f55099c965376dd88eeb43 Reviewed-on: https://gerrit.libreoffice.org/21380 Tested-by: Jenkins <ci@libreoffice.org> Reviewed-by: Chris Sherlock <chris.sherlock79@gmail.com>
Diffstat (limited to 'vcl/inc/fontinstance.hxx')
-rw-r--r--vcl/inc/fontinstance.hxx9
1 files changed, 5 insertions, 4 deletions
diff --git a/vcl/inc/fontinstance.hxx b/vcl/inc/fontinstance.hxx
index c790a92f1924..54a74d0e3637 100644
--- a/vcl/inc/fontinstance.hxx
+++ b/vcl/inc/fontinstance.hxx
@@ -25,6 +25,7 @@
#include "fontselect.hxx"
#include "fontattributes.hxx"
+#include "impfontmetricdata.hxx"
#include <unordered_map>
@@ -41,16 +42,16 @@ public:
public: // TODO: make data members private
ImplFontCache * mpFontCache;
- FontSelectPattern maFontSelData; // FontSelectionData
- FontAttributes maFontAttributes; // Font attributes
- const ConvertChar* mpConversion; // used e.g. for StarBats->StarSymbol
+ FontSelectPattern maFontSelData; // FontSelectionData
+ ImplFontMetricData maFontMetric; // Font attributes
+ const ConvertChar* mpConversion; // used e.g. for StarBats->StarSymbol
long mnLineHeight;
sal_uLong mnRefCount;
sal_uInt16 mnSetFontFlags; // Flags returned by SalGraphics::SetFont()
short mnOwnOrientation; // text angle if lower layers don't rotate text themselves
short mnOrientation; // text angle in 3600 system
- bool mbInit; // true if maFontAttributes member is valid
+ bool mbInit; // true if maFontMetric member is valid
void AddFallbackForUnicode( sal_UCS4, FontWeight eWeight, const OUString& rFontName );
bool GetFallbackForUnicode( sal_UCS4, FontWeight eWeight, OUString* pFontName ) const;